@@ -5,11 +5,11 @@ import ssl
 
 class SenseConnect:
     #initialising the constructor
-    def __init__(self, domain='localhost', port='4848', userdirectory='', userid='', conntype='cert'):
-        self.ws = self.create_connection(domain, port, userdirectory, userid, conntype)
+    def __init__(self, domain='localhost', port='4848', userdirectory='', userid='', certPath='.', conntype='cert'):
+        self.ws = self.create_connection(domain, port, userdirectory, userid, certPath, conntype)
         self.qlikcall = SenseCalls()
 
-    def create_connection(self, domain, port, userdirectory, userid, conntype):
+    def create_connection(self, domain, port, userdirectory, userid, certPath, conntype):
         print('Connection initiated!')
         if domain=='localhost':
             try:
@@ -21,10 +21,10 @@ class SenseConnect:
                 return 'Make sure you have opened your local qliksense desktop app before running this.'
         else:
             qlik_server_url = f"wss://{domain}:{port}/app"
-            certs = ({"ca_certs":'root.pem',
-                      "certfile": 'client.pem',
-                      "keyfile": 'client_key.pem',
-                      "cert_reqs": ssl.CERT_REQUIRED,
+            certs = ({"ca_certs"   : r''+certPath+'/root.pem',
+                      "certfile"   : r''+certPath+'/client.pem',
+                      "keyfile"    : r''+certPath+'/client_key.pem',
+                      "cert_reqs"  : ssl.CERT_REQUIRED,
                       "server_side": False})
             ssl.match_hostname = lambda cert, hostname: True
             return websocket.create_connection(qlik_server_url, 
@@ -44,16 +44,18 @@ class SenseConnect:
         
     
     # This will give the list of all the apps in workspace
-    def get_list_of_apps(self):
-        app_list = []
+    def app_overview(self, appID=''):
         self.ws.send(self.qlikcall.get_doc_list())
         result = json.loads(self.ws.recv())
         if 'method' in result.keys():
             # result = self.ws.recv()
             result = json.loads(self.ws.recv())
-        for doclist in result['result']['qDocList']:
-            app_list.append(doclist['qTitle'])           
-        return app_list
+        if appID!='':
+            for doclist in result['result']['qDocList']:
+                if doclist['qDocId']==appID:
+                    return doclist
+            return 'App ID not found.'           
+        return result['result']['qDocList']
     
     # This will give the last updated/reloaded date&time of an app
     def get_last_updated_status(self, appname):
